==> ejc-bid-impl-3.0.0-20220323.110522-179-sources.jar: com/ejianc/business/bid/bean/PrequaliFicationEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 资格预审
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_prequalification")
public class PrequaliFicationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编码
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态
    @TableField(value="engineering_code")
    private java.lang.String engineeringCode; // 工程编码
    @TableField(value="engineering_id")
    private java.lang.Long engineeringId; // 工程名称
    @TableField(value="engineering_name")
    private java.lang.String engineeringName; // 工程名称
    @TableField(value="estimated_examine_date")
    private java.util.Date estimatedExamineDate; // 预审日期
    @TableField(value="estimated_examine_result")
    private java.lang.Integer estimatedExamineResult; // 预审结果 1通过 0未通过
    @TableField(value="estimated_examine_result_name")
    private java.lang.String estimatedExamineResultName; // 预审结果
    @TableField(value="fail_reason")
    private java.lang.String failReason; // 未通过原因
    @TableField(value="built_constructor")
    private java.lang.String builtConstructor; // 建造师
    @TableField(value="technically_conscientious_person")
    private java.lang.String technicallyConscientiousPerson; // 拟派技术负责人
    @TableField(value="remark")
    private java.lang.String remark; // 备注
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="enroll_id")
    private java.lang.Long enrollId; // 报名ID
    @TableField(value="is_stop")
    private java.lang.Integer isStop; // 是否停止
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 编制人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 编制人
    @TableField(value="bill_date")
    private java.util.Date billDate; // 编制日期
    @TableField(value="make_org_id")
    private java.lang.Long makeOrgId; // 编制机构
    @TableField(value="make_org_name")
    private java.lang.String makeOrgName; // 编制机构

    @TableField(value="org_code")
    private String orgCode; // 组织编码

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    /**
     * 工程名称
     */
    public Long getEngineeringId() {
        return engineeringId;
    }

    /**
     * 工程名称
     */
    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }

    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程编码
     */
    public java.lang.String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(java.lang.String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 预审日期
     */
    public java.util.Date getEstimatedExamineDate() {
        return estimatedExamineDate;
    }

    /**
     * 预审日期
     */
    public void setEstimatedExamineDate(java.util.Date estimatedExamineDate) {
        this.estimatedExamineDate = estimatedExamineDate;
    }
    /**
     * 预审结果 1通过 0未通过
     */
    public java.lang.Integer getEstimatedExamineResult() {
        return estimatedExamineResult;
    }

    /**
     * 预审结果 1通过 0未通过
     */
    public void setEstimatedExamineResult(java.lang.Integer estimatedExamineResult) {
        this.estimatedExamineResult = estimatedExamineResult;
    }
    /**
     * 预审结果
     */
    public java.lang.String getEstimatedExamineResultName() {
        return estimatedExamineResultName;
    }

    /**
     * 预审结果
     */
    public void setEstimatedExamineResultName(java.lang.String estimatedExamineResultName) {
        this.estimatedExamineResultName = estimatedExamineResultName;
    }

    /**
     *  未通过原因
     */
    public String getFailReason() {
        return failReason;
    }

    /**
     *  未通过原因
     */
    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    /**
     * 建造师
     */
    public java.lang.String getBuiltConstructor() {
        return builtConstructor;
    }

    /**
     * 建造师
     */
    public void setBuiltConstructor(java.lang.String builtConstructor) {
        this.builtConstructor = builtConstructor;
    }
    /**
     * 拟派技术负责人
     */
    public java.lang.String getTechnicallyConscientiousPerson() {
        return technicallyConscientiousPerson;
    }

    /**
     * 拟派技术负责人
     */
    public void setTechnicallyConscientiousPerson(java.lang.String technicallyConscientiousPerson) {
        this.technicallyConscientiousPerson = technicallyConscientiousPerson;
    }
    /**
     * 备注
     */
    public java.lang.String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(java.lang.String remark) {
        this.remark = remark;
    }
    /**
     * 所属组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 报名ID
     */
    public java.lang.Long getEnrollId() {
        return enrollId;
    }

    /**
     * 报名ID
     */
    public void setEnrollId(java.lang.Long enrollId) {
        this.enrollId = enrollId;
    }
    /**
     * 是否停止
     */
    public java.lang.Integer getIsStop() {
        return isStop;
    }

    /**
     * 是否停止
     */
    public void setIsStop(java.lang.Integer isStop) {
        this.isStop = isStop;
    }
    /**
     * 编制人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 编制人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 编制人
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 编制人
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 编制日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 编制日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 编制机构
     */
    public java.lang.Long getMakeOrgId() {
        return makeOrgId;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgId(java.lang.Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    /**
     * 编制机构
     */
    public java.lang.String getMakeOrgName() {
        return makeOrgName;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgName(java.lang.String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    
}

==> ejc-bid-impl-3.0.0-20231008.020252-374-sources.jar: com/ejianc/business/bid/bean/PrequaliFicationEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 资格预审
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_prequalification")
public class PrequaliFicationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="engineering_code")
    private String engineeringCode; // 工程编码
    @TableField(value="engineering_id")
    private Long engineeringId; // 工程名称
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="estimated_examine_date")
    private java.util.Date estimatedExamineDate; // 预审日期
    @TableField(value="estimated_examine_result")
    private Integer estimatedExamineResult; // 预审结果 1通过 0未通过
    @TableField(value="estimated_examine_result_name")
    private String estimatedExamineResultName; // 预审结果
    @TableField(value="fail_reason")
    private String failReason; // 未通过原因
    @TableField(value="built_constructor")
    private String builtConstructor; // 建造师
    @TableField(value="technically_conscientious_person")
    private String technicallyConscientiousPerson; // 拟派技术负责人
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 所属组织
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="enroll_id")
    private Long enrollId; // 报名ID
    @TableField(value="is_stop")
    private Integer isStop; // 是否停止
    @TableField(value="employee_id")
    private Long employeeId; // 编制人
    @TableField(value="employee_name")
    private String employeeName; // 编制人
    @TableField(value="bill_date")
    private java.util.Date billDate; // 编制日期
    @TableField(value="make_org_id")
    private Long makeOrgId; // 编制机构
    @TableField(value="make_org_name")
    private String makeOrgName; // 编制机构

    @TableField(value="org_code")
    private String orgCode; // 组织编码

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }



    /**
     * 工程名称
     */
    public Long getEngineeringId() {
        return engineeringId;
    }

    /**
     * 工程名称
     */
    public void setEngineeringId(Long engineeringId) {
        this.engineeringId = engineeringId;
    }

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 工程编码
     */
    public String getEngineeringCode() {
        return engineeringCode;
    }

    /**
     * 工程编码
     */
    public void setEngineeringCode(String engineeringCode) {
        this.engineeringCode = engineeringCode;
    }
    /**
     * 工程名称
     */
    public String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称
     */
    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 预审日期
     */
    public java.util.Date getEstimatedExamineDate() {
        return estimatedExamineDate;
    }

    /**
     * 预审日期
     */
    public void setEstimatedExamineDate(java.util.Date estimatedExamineDate) {
        this.estimatedExamineDate = estimatedExamineDate;
    }
    /**
     * 预审结果 1通过 0未通过
     */
    public Integer getEstimatedExamineResult() {
        return estimatedExamineResult;
    }

    /**
     * 预审结果 1通过 0未通过
     */
    public void setEstimatedExamineResult(Integer estimatedExamineResult) {
        this.estimatedExamineResult = estimatedExamineResult;
    }
    /**
     * 预审结果
     */
    public String getEstimatedExamineResultName() {
        return estimatedExamineResultName;
    }

    /**
     * 预审结果
     */
    public void setEstimatedExamineResultName(String estimatedExamineResultName) {
        this.estimatedExamineResultName = estimatedExamineResultName;
    }

    /**
     *  未通过原因
     */
    public String getFailReason() {
        return failReason;
    }

    /**
     *  未通过原因
     */
    public void setFailReason(String failReason) {
        this.failReason = failReason;
    }

    /**
     * 建造师
     */
    public String getBuiltConstructor() {
        return builtConstructor;
    }

    /**
     * 建造师
     */
    public void setBuiltConstructor(String builtConstructor) {
        this.builtConstructor = builtConstructor;
    }
    /**
     * 拟派技术负责人
     */
    public String getTechnicallyConscientiousPerson() {
        return technicallyConscientiousPerson;
    }

    /**
     * 拟派技术负责人
     */
    public void setTechnicallyConscientiousPerson(String technicallyConscientiousPerson) {
        this.technicallyConscientiousPerson = technicallyConscientiousPerson;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 所属组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 报名ID
     */
    public Long getEnrollId() {
        return enrollId;
    }

    /**
     * 报名ID
     */
    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }
    /**
     * 是否停止
     */
    public Integer getIsStop() {
        return isStop;
    }

    /**
     * 是否停止
     */
    public void setIsStop(Integer isStop) {
        this.isStop = isStop;
    }
    /**
     * 编制人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 编制人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 编制人
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 编制人
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 编制日期
     */
    public java.util.Date getBillDate() {
        return billDate;
    }

    /**
     * 编制日期
     */
    public void setBillDate(java.util.Date billDate) {
        this.billDate = billDate;
    }
    /**
     * 编制机构
     */
    public Long getMakeOrgId() {
        return makeOrgId;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgId(Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    /**
     * 编制机构
     */
    public String getMakeOrgName() {
        return makeOrgName;
    }

    /**
     * 编制机构
     */
    public void setMakeOrgName(String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    
}
